@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,8 +21,6 @@
 
 package com.openexchange.authentication.kerberos.impl;
 
-import static com.openexchange.authentication.LoginExceptionCodes.INVALID_CREDENTIALS_MISSING_CONTEXT_MAPPING;
-import static com.openexchange.authentication.LoginExceptionCodes.INVALID_CREDENTIALS_MISSING_USER_MAPPING;
 import static com.openexchange.authentication.kerberos.impl.ConfigurationProperty.PROXY_DELIMITER;
 import static com.openexchange.authentication.kerberos.impl.ConfigurationProperty.PROXY_USER;
 import java.util.List;
@@ -39,6 +37,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.ldap.LdapExceptionCode;
+import com.openexchange.java.Strings;
 import com.openexchange.kerberos.ClientPrincipal;
 import com.openexchange.kerberos.KerberosService;
 import com.openexchange.tools.encoding.Base64;
@@ -87,7 +86,7 @@ public class KerberosAuthentication implements AuthenticationService {
                 proxyAs = uid.substring(uid.indexOf(proxyDelimiter) + proxyDelimiter.length(), uid.length());
                 uid = uid.substring(0, uid.indexOf(proxyDelimiter));
                 boolean foundProxy = false;
-                for (final String pu : proxyUser.split(",")) {
+                for (final String pu : Strings.splitByComma(proxyUser)) {
                     if (pu.trim().equalsIgnoreCase(uid)) {
                         foundProxy = true;
                         break;
@@ -108,7 +107,8 @@ public class KerberosAuthentication implements AuthenticationService {
         final String[] splitted = split(principal.getName());
         final int ctxId = contextService.getContextId(splitted[0]);
         if (ContextStorage.NOT_FOUND == ctxId) {
-            throw INVALID_CREDENTIALS_MISSING_CONTEXT_MAPPING.create(splitted[0]);
+            LOG.debug("Missing context mapping for context \"{}\". Login failed.", splitted[0]);
+            throw LoginExceptionCodes.INVALID_CREDENTIALS.create();
         }
         final Context ctx = contextService.getContext(ctxId);
         final int userId;
@@ -120,7 +120,8 @@ public class KerberosAuthentication implements AuthenticationService {
             }
         } catch (OXException e) {
             if (LdapExceptionCode.USER_NOT_FOUND.equals(e)) {
-                throw INVALID_CREDENTIALS_MISSING_USER_MAPPING.create(splitted[1]);
+                LOG.debug("Missing user mapping for user \"{}\". Login failed.", splitted[1]);
+                throw LoginExceptionCodes.INVALID_CREDENTIALS.create();
             }
             throw e;
         }
